==> ak-blanket-6.0.0.tgz: package/README.md <==
[![AtlasKit component registry](https://img.shields.io/badge/AtlasKit-components-FF5230.svg)](http://aui-cdn.atlassian.com/atlaskit/registry/)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://Commitizen.github.io/cz-cli/)
[![semantic-release](https://img.shields.io/badge/GitHub-semantic_release-ffab00.svg)](https://github.com/semantic-release/semantic-release)
[![Report an issue](https://img.shields.io/badge/Report-an_issue-6554C0.svg)](https://ecosystem.atlassian.net/browse/AK)
[![Ask in our forum](https://img.shields.io/badge/Ask-in_our_forum-6554C0.svg)](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-blanket,ak-blanket@6.0.0)

# Blanket

The main purpose of the blanket component is to provide the overlay layer for components such as a modal dialog or a tooltip.

![Example blanket](https://bytebucket.org/atlassian/atlaskit/raw/8456ffce6a0d6fda91591118db3f6f0fe2307a9e/packages/ak-blanket/docs/blanket.gif)

## Try it out

Interact with a [live demo of the ak-blanket component](https://aui-cdn.atlassian.com/atlaskit/stories/ak-blanket/6.0.0/).

## Installation

```sh
npm install ak-blanket
```

## Using the component

### HTML

The `ak-blanket` package exports the Blanket [Skate](https://github.com/skatejs/skatejs) component.

Import the component in your JS resource:

#### bundle.js

```javascript
import 'ak-blanket';
```

Now you can use the defined tag in your HTML markup, for example:

#### index.html

```html
<html>
<head>
  <script src="bundle.js"></script>
</head>
<body>
  <!-- ... -->
  <ak-blanket></ak-blanket>
</body>
```

#### with other components

The main purpose of the blanket component is to provide the `overlay` layer for components such as `modal dialog` or `tooltip`. It can be achieved like this:

```js
define('modal-dialog-component', () => {
 attached(elem) {
   window.addEventListener('activate', doSomethingWhenBlanketClicked(elem));
 },
 detached(elem) {
   window.removeEventListener('activate', doSomethingWhenBlanketClicked(elem));
 },
 render(elem) {
   return (
     <div>
       <ak-blanket clickable tinted />
       <div>the rest of the awesome component here</div>
     </div>
   );
 })
```

It emits the 'activate' event when clicked/touched.
Blanket component doesn't have the z-index style, so make sure you put it into an appropriate DOM position.
For the purpose of simplicity blanket doesn't have any `show/hide` functionality. Since the main use of it suppose to be inside `popup` elements it would appear/disappear with the parent element.

### React

This is a standard web component, if you want to use it in your React app, use the Skate.js [React integration](https://github.com/webcomponents/react-integration).

```js
import Blanket from 'ak-blanket';
import reactify from 'skatejs-react-integration';

const ReactComponent = reactify(Blanket, {});

ReactDOM.render(<ReactComponent />, container);
```

<a name="Blanket"></a>

## Blanket
**Kind**: global class  
* Properties

    *  [blanket.isTinted](#Blanket+isTinted) : <code>Boolean</code>
    *  [blanket.onBlanketClicked](#Blanket+onBlanketClicked) : <code>function</code>

<a name="new_Blanket_new"></a>

### new Blanket()
A blanket which is placed over other page content

**JS Example**
```js
import Blanket from 'ak-blanket';
ReactDOM.render(<Blanket />, container);
```
<a name="Blanket+isTinted"></a>

### blanket.isTinted : <code>Boolean</code>
Whether the blanket has a tinted background color

**Kind**: instance property of <code>[Blanket](#Blanket)</code>  
**Default**: <code>false</code>  
<a name="Blanket+onBlanketClicked"></a>

### blanket.onBlanketClicked : <code>function</code>
Handler function to be called when the blanket is clicked

**Kind**: instance property of <code>[Blanket](#Blanket)</code>  

## Support and feedback

### We're here to help!

Let us know what you think of our components and docs, your feedback is really important for us.

### Community support

Ask a question in our [forum](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-blanket,ak-blanket@6.0.0).

Check [if someone has already asked the same question before](https://answers.atlassian.com/questions/topics/42926171/atlaskit).


### Create a support ticket

Are you in trouble? [Let us know](https://ecosystem.atlassian.net/browse/AK)!

==> ak-blanket-6.0.1.tgz: package/README.md <==
[![AtlasKit component registry](https://img.shields.io/badge/AtlasKit-components-FF5230.svg)](http://aui-cdn.atlassian.com/atlaskit/registry/)
[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://Commitizen.github.io/cz-cli/)
[![semantic-release](https://img.shields.io/badge/GitHub-semantic_release-ffab00.svg)](https://github.com/semantic-release/semantic-release)
[![Report an issue](https://img.shields.io/badge/Report-an_issue-6554C0.svg)](https://ecosystem.atlassian.net/browse/AK)
[![Ask in our forum](https://img.shields.io/badge/Ask-in_our_forum-6554C0.svg)](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-blanket,ak-blanket@6.0.1)

# Blanket

The main purpose of the blanket component is to provide the overlay layer for components such as a modal dialog or a tooltip.

![Example blanket](https://bytebucket.org/atlassian/atlaskit/raw/e24de9465c4754a66afde698a0e9fe2941196a1d/packages/ak-blanket/docs/blanket.gif)

## Try it out

Interact with a [live demo of the ak-blanket component](https://aui-cdn.atlassian.com/atlaskit/stories/ak-blanket/6.0.1/).

## Installation

```sh
npm install ak-blanket
```

## Using the component

Import the component in your React app as follows:

```js
import Blanket from 'ak-blanket';
ReactDOM.render(<Blanket />, container);
```

There is an `onBlanketClicked` function prop, which is useful for hiding the blanket when the user clicks it.

No custom z-index style is applied, so make sure you put it into an appropriate DOM position.

For the purpose of simplicity blanket doesn't have any `show/hide` functionality. Since the main use of it suppose to be inside `popup` elements it would appear/disappear with the parent element.

<a name="Blanket"></a>

## Blanket
**Kind**: global class  
* Properties

    *  [blanket.isTinted](#Blanket+isTinted) : <code>Boolean</code>
    *  [blanket.onBlanketClicked](#Blanket+onBlanketClicked) : <code>function</code>

<a name="new_Blanket_new"></a>

### new Blanket()
A blanket which is placed over other page content

**JS Example**
```js
import Blanket from 'ak-blanket';
ReactDOM.render(<Blanket />, container);
```
<a name="Blanket+isTinted"></a>

### blanket.isTinted : <code>Boolean</code>
Whether the blanket has a tinted background color

**Kind**: instance property of <code>[Blanket](#Blanket)</code>  
**Default**: <code>false</code>  
<a name="Blanket+onBlanketClicked"></a>

### blanket.onBlanketClicked : <code>function</code>
Handler function to be called when the blanket is clicked

**Kind**: instance property of <code>[Blanket](#Blanket)</code>  

## Support and feedback

### We're here to help!

Let us know what you think of our components and docs, your feedback is really important for us.

### Community support

Ask a question in our [forum](https://answers.atlassian.com/questions/ask?title=AtlasKit%3A%20&topics=atlaskit,ak-blanket,ak-blanket@6.0.1).

Check [if someone has already asked the same question before](https://answers.atlassian.com/questions/topics/42926171/atlaskit).


### Create a support ticket

Are you in trouble? [Let us know](https://ecosystem.atlassian.net/browse/AK)!
